@@ -551,7 +551,7 @@ BMPreadcolormap(FILE *         const ifP,
     xel * colormap;
     unsigned int bytesRead;
 
-    colormap = pnm_allocrow(cmapsize);
+    colormap = pnm_allocrow(MAX(1, cmapsize));
     
     bytesRead = 0;  /* initial value */
 
