@@ -16,6 +16,8 @@
  */
 
 #define _BSD_SOURCE 1   /* Make sure strdup() is in string.h */
+#define _XOPEN_SOURCE 500  /* Make sure strdup() is in string.h */
+
 #include "config.h"
 
 #include <stdio.h>
@@ -27,6 +29,8 @@
  
 #include <getopt.h>			/* system or ../lib */
 
+#include "nstring.h"
+
 #include "types.h"
 #include "macros.h"
 #include "bit-io.h"
@@ -603,19 +607,19 @@ read_parameter_file (param_t *params, FILE *file)
       /*
        *  Extract value of parameter
        */
-      for (value = b + 1; isspace (*value); value++) 
+      for (value = b + 1; ISSPACE (*value); value++) 
 	 ;				/* Delete leading spaces */
 
-      for (b = value + strlen (value) - 1; b >= value && isspace (*b); b--)
+      for (b = value + strlen (value) - 1; b >= value && ISSPACE (*b); b--)
 	 *b = '\0';			/* Delete trailing spaces. */
 
       /*
        *  Extract parameter name
        */
-      for (name = buffer; isspace (*name); name++) 
+      for (name = buffer; ISSPACE (*name); name++) 
 	 ;				/* Delete leading spaces */
 
-      for (b = name + strlen (name) - 1; b >= name && isspace (*b); b--)
+      for (b = name + strlen (name) - 1; b >= name && ISSPACE (*b); b--)
 	 *b = '\0';			/* Delete trailing spaces. */
 
       pind = get_parameter_index (params, name);
