@@ -36,7 +36,7 @@ struct cmdlineInfo {
     const char *inputFilespec;  /* Filespecs of input files */
     char *outname;         /* output filename, less "_icon" */
     unsigned int verbose;
-} cmdline;
+};
 
 
 
