@@ -575,12 +575,12 @@ clusterConvertRow(struct converter * const converterP,
                   bit                      bitrow[]) {
 
     struct clusterState * const stateP = converterP->stateP;
-    unsigned int const radius = stateP->radius;
+    unsigned int const diameter = 2 * stateP->radius;
 
     unsigned int col;
 
     for (col = 0; col < converterP->cols; ++col)
-        if (grayrow[col] > stateP->clusterMatrix[row % radius][col % radius])
+        if (grayrow[col] > stateP->clusterMatrix[row % diameter][col % diameter])
             bitrow[col] = PBM_WHITE;
         else
             bitrow[col] = PBM_BLACK;
@@ -592,10 +592,11 @@ static void
 clusterDestroy(struct converter * const converterP) {
 
     struct clusterState * const stateP = converterP->stateP;
+    unsigned int const diameter = 2 * stateP->radius;
 
     unsigned int row;
 
-    for (row = 0; row < stateP->radius; ++row)
+    for (row = 0; row < diameter; ++row)
         free(stateP->clusterMatrix[row]);
 
     free(stateP->clusterMatrix);
@@ -611,6 +612,7 @@ createClusterConverter(unsigned int const radius,
                        gray         const maxval) {
     
     int const clusterNormalizer = radius * radius * 2;
+    unsigned int const diameter = 2 * radius;
 
     struct converter converter;
     struct clusterState * stateP;
@@ -624,13 +626,13 @@ createClusterConverter(unsigned int const radius,
 
     stateP->radius = radius;
 
-    MALLOCARRAY_NOFAIL(stateP->clusterMatrix, radius);
-    for (row = 0; row < radius; ++row) {
+    MALLOCARRAY_NOFAIL(stateP->clusterMatrix, diameter);
+    for (row = 0; row < diameter; ++row) {
         unsigned int col;
 
-        MALLOCARRAY_NOFAIL(stateP->clusterMatrix[row], radius);
+        MALLOCARRAY_NOFAIL(stateP->clusterMatrix[row], diameter);
         
-        for (col = 0; col < radius; ++col) {
+        for (col = 0; col < diameter; ++col) {
             int val;
             switch (radius) {
             case 3: val = cluster3[row][col]; break;
