@@ -49,7 +49,7 @@ struct density {
         /* Same as 'horiz', but vertical */
 };
 
-struct cmdline_info {
+static struct cmdline_info {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
      */
