@@ -55,6 +55,9 @@ Software copyrights will soon need family trees... :-)
 
 */
 
+/* On AIX, _XOPEN_SOURCE keeps inttypes.h from conflicting with tiffio.h */
+#define _XOPEN_SOURCE
+
 #include "pnm.h"
 #include <math.h>
 /* float.h used to be included only if __osf__ was defined.  On some
