@@ -66,6 +66,7 @@
 #include "ppmfloyd.h"
 #include "pbm.h"
 #include "ilbm.h"
+#include "mallocvar.h"
 
 /*#define DEBUG*/
 
@@ -117,8 +118,6 @@ static void store_bodyrow ARGS((unsigned char *row, int len));
 static int runbyte1 ARGS((int bytes));
 static pixel * next_pixrow ARGS((FILE *fp, int row));
 static int * make_val_table ARGS((int oldmaxval, int newmaxval));
-static void * xmalloc ARGS((int bytes));
-#define MALLOC(n, type)     (type *)xmalloc((n) * sizeof(type))
 static void init_read ARGS((FILE *fp, int *colsP, int *rowsP, pixval *maxvalP, int *formatP, int readall));
 static void write_body_rows ARGS((void));
 static void write_camg ARGS((void));
@@ -793,7 +792,7 @@ main(argc, argv)
 
     if( maskmethod != mskNone ) {
         if( transpname ) {
-            transpColor = MALLOC(1, pixel);
+            MALLOCVAR_NOFAIL(transpColor);
             *transpColor = ppm_parsecolor(transpname, maxval);
         }
         if( maskfile ) {
@@ -811,11 +810,11 @@ main(argc, argv)
 
     if( mode != MODE_CMAP ) {
         register int i;
-        coded_rowbuf = MALLOC(RowBytes(cols), unsigned char);
+        MALLOCARRAY_NOFAIL(coded_rowbuf, RowBytes(cols));
         for( i = 0; i < RowBytes(cols); i++ )
             coded_rowbuf[i] = 0;
         if( DO_COMPRESS )
-            compr_rowbuf = MALLOC(WORSTCOMPR(RowBytes(cols)), unsigned char);
+            MALLOCARRAY_NOFAIL(compr_rowbuf, WORSTCOMPR(RowBytes(cols)));
     }
 
     switch( mode ) {
@@ -1010,7 +1009,7 @@ compute_ham_cmap(cols, rows, maxval, maxcolors, colorsP, hbits)
     pm_message("initializing HAM colormap...");
 
     colors = 1<<(3*hbits);
-    hmap = malloc(colors * sizeof(hentry));
+    MALLOCARRAY(hmap, colors);
     if (hmap == NULL)
         pm_error("Unable to allocate memory for HAM colormap.");
     hmaxval = pm_bitstomaxval(hbits);
@@ -1128,7 +1127,7 @@ ppm_to_ham(fp, cols, rows, maxval, colormap, colors, cmapmaxval, hamplanes)
         switch( hammapmode ) {
             case HAMMODE_GRAY:
                 colors = hamcolors;
-                colormap = MALLOC(colors, pixel);
+                MALLOCARRAY_NOFAIL(colormap, colors);
 #ifdef DEBUG
                 pm_message("generating grayscale colormap");
 #endif
@@ -1152,7 +1151,7 @@ ppm_to_ham(fp, cols, rows, maxval, colormap, colors, cmapmaxval, hamplanes)
 
                 entries = (hamcolors-1)/7;
                 colors = 7*entries+1;
-                colormap = MALLOC(colors, pixel);
+                MALLOCARRAY_NOFAIL(colormap, colors);
                 step = (double)MAXCOLVAL / (double)entries;
 
                 PPM_ASSIGN(colormap[0], 0, 0, 0);
@@ -1293,7 +1292,7 @@ do_ham_body(ifp, ofp, cols, rows, maxval, hammaxval, nPlanes, colormap, colors)
     int colbits;
     int hamcode_red, hamcode_green, hamcode_blue;
 
-    raw_rowbuf = MALLOC(cols, rawtype);
+    MALLOCARRAY_NOFAIL(raw_rowbuf, cols);
 
     cht = ppm_colorrowtocolorhash(colormap, colors);
     cht2 = ppm_alloccolorhash();
@@ -1531,9 +1530,9 @@ do_deep_body(ifp, ofp, cols, rows, maxval, bitspercolor)
     rawtype *redbuf, *greenbuf, *bluebuf;
     int newmaxval;
 
-    redbuf   = MALLOC(cols, rawtype);
-    greenbuf = MALLOC(cols, rawtype);
-    bluebuf  = MALLOC(cols, rawtype);
+    MALLOCARRAY_NOFAIL(redbuf,   cols);
+    MALLOCARRAY_NOFAIL(greenbuf, cols);
+    MALLOCARRAY_NOFAIL(bluebuf,  cols);
 
     newmaxval = pm_bitstomaxval(bitspercolor);
     if( maxval != newmaxval ) {
@@ -1677,9 +1676,9 @@ do_dcol_body(ifp, ofp, cols, rows, maxval, dcol)
     rawtype *redbuf, *greenbuf, *bluebuf;
     int *redtable, *greentable, *bluetable;
 
-    redbuf   = MALLOC(cols, rawtype);
-    greenbuf = MALLOC(cols, rawtype);
-    bluebuf  = MALLOC(cols, rawtype);
+    MALLOCARRAY_NOFAIL(redbuf,   cols);
+    MALLOCARRAY_NOFAIL(greenbuf, cols);
+    MALLOCARRAY_NOFAIL(bluebuf,  cols);
 
     redtable   = make_val_table(maxval, pm_bitstomaxval(dcol->r));
     greentable = make_val_table(maxval, pm_bitstomaxval(dcol->g));
@@ -1750,8 +1749,9 @@ ppm_to_std(fp, cols, rows, maxval, colormap, colors, cmapmaxval,
         int i, *table;
         pixel *newcmap;
 
+        newcmap = ppm_allocrow(colors);
         table = make_val_table(cmapmaxval, maxval);
-        for( i = 0; i < colors; i++ )
+        for (i = 0; i < colors; ++i)
             PPM_ASSIGN(newcmap[i], 
                        table[PPM_GETR(colormap[i])], 
                        table[PPM_GETG(colormap[i])], 
@@ -1836,7 +1836,7 @@ do_std_body(ifp, ofp, cols, rows, maxval, colormap, colors, nPlanes)
     int usehash = 1;
     colorhash_table cht;
 
-    raw_rowbuf = MALLOC(cols, rawtype);
+    MALLOCARRAY_NOFAIL(raw_rowbuf, cols);
     cht = ppm_colorrowtocolorhash(colormap, colors);
     if( floyd )
         fi = ppm_fs_init(cols, maxval, FS_ALTERNATE);
@@ -1905,7 +1905,7 @@ ppm_to_rgb8(ifp, cols, rows, maxval)
 
     maskmethod = 0;     /* no masking - RGB8 uses genlock bits */
     compmethod = 4;     /* RGB8 files are always compressed */
-    compr_row = MALLOC(cols * 4, unsigned char);
+    MALLOCARRAY_NOFAIL(compr_row, cols * 4);
 
     if( maxval != 255 ) {
         pm_message("maxval is not 255 - automatically rescaling colors");
@@ -1993,7 +1993,7 @@ ppm_to_rgbn(ifp, cols, rows, maxval)
 
     maskmethod = 0;     /* no masking - RGBN uses genlock bits */
     compmethod = 4;     /* RGBN files are always compressed */
-    compr_row = MALLOC(cols * 2, unsigned char);
+    MALLOCARRAY_NOFAIL(compr_row, cols * 2);
 
     if( maxval != 15 ) {
         pm_message("maxval is not 15 - automatically rescaling colors");
@@ -2354,12 +2354,12 @@ store_bodyrow(row, len)
 {
     int idx = cur_block->used;
     if( idx >= ROWS_PER_BLOCK ) {
-        cur_block->next = MALLOC(1, bodyblock);
+        MALLOCVAR_NOFAIL(cur_block->next);
         cur_block = cur_block->next;
         cur_block->used = idx = 0;
         cur_block->next = NULL;
     }
-    cur_block->row[idx] = MALLOC(len, unsigned char);
+    MALLOCARRAY_NOFAIL(cur_block->row[idx], len);
     cur_block->len[idx] = len;
     memcpy(cur_block->row[idx], row, len);
     cur_block->used++;
@@ -2475,7 +2475,7 @@ make_val_table(oldmaxval, newmaxval)
     int i;
     int *table;
 
-    table = MALLOC(oldmaxval + 1, int);
+    MALLOCARRAY_NOFAIL(table, oldmaxval + 1);
     for(i = 0; i <= oldmaxval; i++ )
         table[i] = (i * newmaxval + oldmaxval/2) / oldmaxval;
 
@@ -2483,18 +2483,6 @@ make_val_table(oldmaxval, newmaxval)
 }
 
 
-static void *
-xmalloc(bytes)
-    int bytes;
-{
-    void *mem;
-
-    mem = malloc(bytes);
-    if( mem == NULL )
-        pm_error("out of memory allocating %d bytes", bytes);
-    return mem;
-}
-
 
 static int  gFormat;
 static int  gCols;
