@@ -146,7 +146,7 @@ getHostName(void) {
 
     rc = uname(&utsname);
 
-    if (rc != 0)
+    if (rc < 0)
         pm_error("Unable to find out host name.  "
                  "uname() failed with errno %d (%s)", errno, strerror(errno));
 
@@ -1054,11 +1054,7 @@ GetRemoteFrame(MpegFrame * const frameP,
                the last message for a frame) the I/O server sends.
             */
             int numBytes;  /* Number of data bytes in message */
-            FILE * filePtr;
-            char fileName[256];
-
-            sprintf(fileName, "/tmp/foobar%d", machineNumber);
-            filePtr = fopen(fileName, "wb");
+            FILE * filePtr = pm_tmpfile();
 
             /* read in stuff, write to file, perform local conversion */
             do {
@@ -1073,10 +1069,7 @@ GetRemoteFrame(MpegFrame * const frameP,
                 fwrite(buffer, 1, numBytes, filePtr);
             } while ( numBytes == sizeof(buffer) );
             fflush(filePtr);
-            fclose(filePtr);
-
-            /* now do slave conversion */
-            filePtr = fopen(fileName, "rb");
+            rewind(filePtr);
             ReadFrameFile(frameP, filePtr, slaveConversion);
             fclose(filePtr);
         } else {
