@@ -752,7 +752,7 @@ ReadParamFile(const char *    const fileName,
             charPtr = SkipSpacesTabs(&input[13]);
             if ( strncmp(charPtr, "stdin", 5) == 0 ||
                  strncmp(charPtr, "STDIN", 5) == 0 ) {
-                SetStdinInput(inputSourceP);
+                SetStdinInput(gopInputSourceP);
             }
             strcpy(currentGOPPath, charPtr);
         } else if ( strncmp(input, "GOP_INPUT", 9) == 0 ) {
@@ -777,7 +777,7 @@ ReadParamFile(const char *    const fileName,
             charPtr = SkipSpacesTabs(&input[9]);
             if ( strncmp(charPtr, "stdin", 5) == 0 ||
                  strncmp(charPtr, "STDIN", 5) == 0 )
-                SetStdinInput(paramP->inputSourceP);
+                SetStdinInput(inputSourceP);
             strcpy(currentPath, charPtr);
             optionSeen[OPTION_INPUT_DIR] = TRUE;
         } else if ( strncmp(input, "INPUT_CONVERT", 13) == 0 ) {
