@@ -557,6 +557,10 @@ getUserFrameFile(void *       const handle,
     
     struct inputSource * const inputSourceP = (struct inputSource *) handle;
 
+    if (inputSourceP->stdinUsed)
+        pm_error("You cannot combine frames from Standard Input.");
+            /* Because Caller detects end of frames by EOF */
+    
     if (frameNumber >= inputSourceP->numInputFiles)
         *ifPP = NULL;
     else {
