@@ -139,77 +139,79 @@ openFile(struct inputSource * const inputSourceP,
          const char *         const conversion, 
          FILE **              const ifPP) {
 
-    const char * fileName;
-    const char * fullFileName;
-
-    GetNthInputFileName(inputSourceP, frameNumber, &fileName);
-
-    asprintfN(&fullFileName, "%s/%s", currentPath, fileName);
-
-    CurrFile = fullFileName;
-
-    if (fileType == ANY_FILE_TYPE) {
-        char    command[1024];
-        const char *convertPtr;
-        char *commandPtr;
-        const char * charPtr;
-
-        if (inputSourceP->stdinUsed)
+    if (inputSourceP->stdinUsed) {
+        if (fileType == ANY_FILE_TYPE)
             pm_error(
-                    "ERROR : You cannot use a converter on frames when "
-                    "you supply them as Standard Input.  Either specify "
-                    "INPUT_CONVERTER * in the parameter file or supply the "
-                    "frames in files by specifying a directory with "
-                    "INPUT_DIRECTORY in the parameter file.");
+                "ERROR : You cannot use a converter on frames when "
+                "you supply them as Standard Input.  Either specify "
+                "INPUT_CONVERTER * in the parameter file or supply the "
+                "frames in files by specifying a directory with "
+                "INPUT_DIRECTORY in the parameter file.");
+            
+        *ifPP = stdin;
+    } else {
+        const char * fileName;
+        const char * fullFileName;
 
-        /* replace every occurrence of '*' with fullFileName */
-        convertPtr = conversion;
-        commandPtr = command;
-        while ( *convertPtr != '\0' ) {
-            while ( (*convertPtr != '\0') && (*convertPtr != '*') ) {
-                *commandPtr = *convertPtr;
-                commandPtr++;
-                convertPtr++;
-            }
+        GetNthInputFileName(inputSourceP, frameNumber, &fileName);
 
-            if ( *convertPtr == '*' ) {
-                /* copy fullFileName */
-                charPtr = fullFileName;
-                while ( *charPtr != '\0' ) {
-                    *commandPtr = *charPtr;
+        asprintfN(&fullFileName, "%s/%s", currentPath, fileName);
+        
+        CurrFile = fullFileName;
+        
+        if (fileType == ANY_FILE_TYPE) {
+            char command[1024];
+            const char *convertPtr;
+            char *commandPtr;
+            const char * charPtr;
+            
+            /* replace every occurrence of '*' with fullFileName */
+            convertPtr = conversion;
+            commandPtr = command;
+            while (*convertPtr != '\0') {
+                while ((*convertPtr != '\0') && (*convertPtr != '*')) {
+                    *commandPtr = *convertPtr;
                     commandPtr++;
-                    charPtr++;
+                    convertPtr++;
                 }
 
-                convertPtr++;   /* go past '*' */
+                if ( *convertPtr == '*' ) {
+                    /* copy fullFileName */
+                    charPtr = fullFileName;
+                    while ( *charPtr != '\0' ) {
+                        *commandPtr = *charPtr;
+                        commandPtr++;
+                        charPtr++;
+                    }
+                    convertPtr++;   /* go past '*' */
+                }
             }
-        }
-        *commandPtr = '\0';
+            *commandPtr = '\0';
 
-        *ifPP = popen(command, "r");
-        if (*ifPP == NULL) {
-            fprintf(stderr, 
-                    "ERROR:  Couldn't execute input conversion command:\n");
-            fprintf(stderr, "\t%s\n", command);
-            fprintf(stderr, "errno = %d\n", errno);
-            if (ioServer)
-                fprintf(stderr, "IO SERVER:  EXITING!!!\n");
-            else
-                fprintf(stderr, "SLAVE EXITING!!!\n");
-            exit(1);
-        }
-    } else if (inputSourceP->stdinUsed)
-        *ifPP = stdin;
-    else {
-        *ifPP = fopen(fullFileName, "rb");
-        if (*ifPP == NULL)
-            pm_error("Couldn't open input file '%s'", fullFileName);
+            *ifPP = popen(command, "r");
+            if (*ifPP == NULL) {
+                fprintf(stderr, 
+                        "ERROR:  "
+                        "Couldn't execute input conversion command:\n");
+                fprintf(stderr, "\t%s\n", command);
+                fprintf(stderr, "errno = %d\n", errno);
+                if (ioServer)
+                    fprintf(stderr, "IO SERVER:  EXITING!!!\n");
+                else
+                    fprintf(stderr, "SLAVE EXITING!!!\n");
+                exit(1);
+            }
+        } else {
+            *ifPP = fopen(fullFileName, "rb");
+            if (*ifPP == NULL)
+                pm_error("Couldn't open input file '%s'", fullFileName);
 
-        if (baseFormat == JMOVIE_FILE_TYPE)
-            unlink(fullFileName);
+            if (baseFormat == JMOVIE_FILE_TYPE)
+                unlink(fullFileName);
+        }
+        strfree(fullFileName);
+        strfree(fileName);
     }
-    strfree(fullFileName);
-    strfree(fileName);
 }
 
 
