@@ -486,7 +486,7 @@ main(int argc, char *argv[]) {
     { 
         /* Compute characters per pixel in the XPM file */
         int j;
-        for (charsPerPixel = 0, j = ncolors; j; charsPerPixel++)
+        for (charsPerPixel = 0, j = ncolors-1; j > 0; ++charsPerPixel)
             j /= MAXPRINTABLE;
     }
     /* Now generate the character-pixel colormap table. */
