@@ -377,18 +377,19 @@ bitOrderReverse(unsigned char * const bitrow,
             */
         unsigned char th,tl;  /* 16 bit temp ( th << 8 | tl ) */
         tl = 0;
-        for (i = 0, j = lastfullByteIdx; i <= lastfullByteIdx/2; ++i, --j) {
+        for (i = 0, j = lastfullByteIdx+1; i <= lastfullByteIdx/2; ++i, --j) {
             th = bitreverse[bitrow[i]];
             bitrow[i] =
-                bitreverse[0xff & ((bitrow[j]<<8 | bitrow[j+1]) >> (8-m))];
-            bitrow[j+1] = 0xff & ((th<<8 | tl) >> m);
+                bitreverse[0xff & ((bitrow[j-1]<<8 | bitrow[j]) >> (8-m))];
+            bitrow[j] = 0xff & ((th<<8 | tl) >> m);
             tl=th;
         }
-        if (i > j) 
-            /* bitrow[] has an even number of full bytes (lastfullByteIdx is
-               odd), so we overlapped above.  Now we correct.
+        if (i == j) 
+            /* bitrow[] has an odd number of bytes (an even number of
+               full bytes; lastfullByteIdx is odd), so we did all but
+               the center byte above.  We do the center byte now.
             */
-            bitrow[j+1] = 0xff & ((bitreverse[bitrow[i]]<<8|tl ) >> m );
+            bitrow[j] = 0xff & ((bitreverse[bitrow[i]]<<8|tl ) >> m );
     }
 }
 
