@@ -83,6 +83,8 @@
  */
 
 #define _BSD_SOURCE 1   /* Make sure strdup() is in string.h */
+#define _XOPEN_SOURCE 500  /* Make sure strdup() is in string.h */
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -92,6 +94,7 @@
 #include "pam.h"
 #include "shhopt.h"
 #include "nstring.h"
+#include "mallocvar.h"
 
 /*
  *  Structures
@@ -347,7 +350,9 @@ main (int argc, char **argv)
 static Image *
 allocate_image(void)
 {
-    Image * const retVal = (Image *)malloc((unsigned)sizeof(Image));
+    Image * retVal;
+    
+    MALLOCVAR(retVal);
 
     if (retVal != NULL) 
         memset (retVal, 0, (unsigned)sizeof(Image));
@@ -441,9 +446,8 @@ readinit(const char * const name)
         } else {
             openWithPossibleExtension(name, &ifP, &image->name);
         }
-        image->tuple = pnm_readpam(ifP,
-                                   &(image->pam), 
-                                   (unsigned)sizeof(image->pam));
+        image->tuple = pnm_readpam(ifP, &(image->pam), 
+                                   PAM_STRUCT_SIZE(tuple_type));
         fclose (ifP);
         image->pam.file = NULL;
 
@@ -541,19 +545,20 @@ typedef struct {
 static Best *
 allocate_best(void)
 {
-    Best * retVal = (Best *)malloc((unsigned)sizeof(Best)*NUM_BEST);
-    int    i;
+    Best * retVal;
 
-    if (retVal == (Best *)NULL) {
-        return retVal;
-    }
-    for (i = 0; i < NUM_BEST; ++i) {
-        retVal[i].total = ULONG_MAX;
-        retVal[i].x = INT_MAX;
-        retVal[i].y = INT_MAX;
+    MALLOCARRAY(retVal, NUM_BEST);
+
+    if (retVal != NULL) {
+        unsigned int    i;
+        for (i = 0; i < NUM_BEST; ++i) {
+            retVal[i].total = ULONG_MAX;
+            retVal[i].x = INT_MAX;
+            retVal[i].y = INT_MAX;
+        }
     }
     return retVal;
-} /* allocate_best() - end */
+}
 
 /*
  *  Free the Best structure
@@ -1037,7 +1042,7 @@ pnmstitch(const char * const leftfilename,
                     fprintf (stderr,
                              "Images should have matching maxval.  "
                              "The left image has maxval %u, "
-                             "whil the right has maxval %u.",
+                             "while the right has maxval %u.",
                              (unsigned)Left->pam.maxval, 
                              (unsigned)Right->pam.maxval);
                     retval = -6;
@@ -1317,6 +1322,24 @@ Output OutputMethods[] = {
 
 /* Stitcher Methods */
 
+/* These names are for the 8 parameters of a stitch, in any of the 3
+   methods this program presently implements.  Each is a subscript in
+   the parms[] array for the Stitcher object that represents a linear
+   stitching method.  
+   
+   There are also other sets of names for the 8 parameters, such as
+   Rotate_a.  I don't know why.  Maybe historical.
+*/
+
+#define Sliver_A   0
+#define Sliver_B   1
+#define Sliver_C   2
+#define Sliver_D   3
+#define Sliver_xp  4
+#define Sliver_yp  5
+#define Sliver_xpp 6
+#define Sliver_ypp 7
+
 /* Linear Stitcher Methods */
 
 static void
@@ -1331,17 +1354,32 @@ LinearDeAlloc(Stitcher * me)
 static bool
 LinearAlloc(Stitcher * me)
 {
-    me->parms = (float *)malloc (sizeof(float)*8);
-    if (me->parms == (float *)NULL) {
-        return FALSE;
+    bool retval;
+
+    MALLOCARRAY(me->parms, 8);
+    if (me->parms == NULL) 
+        retval = FALSE;
+    else {
+        /* Constraints unset */
+        me->x = INT_MAX;
+        me->y = INT_MAX;
+        me->width = INT_MAX;
+        me->height = INT_MAX;
+        /* Unity transform matrix */
+        me->parms[Sliver_A]   = 1.0;
+        me->parms[Sliver_B]   = 0.0;
+        me->parms[Sliver_C]   = 0.0;
+        me->parms[Sliver_D]   = 0.0;
+        me->parms[Sliver_xp]  = 0.0;
+        me->parms[Sliver_yp]  = 1.0;
+        me->parms[Sliver_xpp] = 0.0;
+        me->parms[Sliver_ypp] = 0.0;
+        retval = TRUE;
     }
-    /* Constraints unset */
-    me->x = INT_MAX;
-    me->y = INT_MAX;
-    me->width = INT_MAX;
-    me->height = INT_MAX;
-    return TRUE;
-} /* LinearAlloc() - end */
+    return retval;
+}
+
+
 
 static void
 LinearConstrain(Stitcher * me, int x, int y, int width, int height)
@@ -1438,15 +1476,6 @@ LinearConstrain(Stitcher * me, int x, int y, int width, int height)
 #define IMAGE_PORTION 64
 #define SKIP_SLIVER   1
 
-#define Sliver_A   0
-#define Sliver_B   1
-#define Sliver_C   2
-#define Sliver_D   3
-#define Sliver_xp  4
-#define Sliver_yp  5
-#define Sliver_xpp 6
-#define Sliver_ypp 7
-
 /* Following global variables are for use by SliverMatch() */
 static unsigned long starPeriod;
     /* The number of events between printing of a "*" progress
@@ -1530,7 +1559,8 @@ allocate_best_array(Best *** const bestP, unsigned const bestSize) {
 
     Best ** best;
     unsigned int i;
-    best = (Best **)malloc(bestSize * sizeof(Best *));
+
+    MALLOCARRAY(best, bestSize);
     if (best == NULL)
         pm_error("No memory for Best array");
     
@@ -1639,7 +1669,9 @@ SliverMatch(Stitcher * me, Image * Left, Image * Right,
          */
     {
         float   minf, maxf;
-        float * features = (float *)malloc(bestSize * sizeof(float));
+        float * features;
+
+        MALLOCARRAY(features, bestSize);
         minf = maxf = 0.0;
         for (in = 0; in < bestSize; ++in) {
             int const offY = yDiff * (in - (bestSize/2));
@@ -1934,6 +1966,9 @@ SliverMatch(Stitcher * me, Image * Left, Image * Right,
     return TRUE;
 } /* SliverMatch() - end */
 
+/* These are not used.  Perhaps they are forerunners of the more
+   expressive Sliver_A, etc. names.
+*/
 #define Linear_a   0
 #define Linear_b   1
 #define Linear_c   2
@@ -2005,22 +2040,21 @@ LinearOutput(Stitcher * me, FILE * fp)
 
 /* BiLinear Stitcher Methods */
 
-#define BiLinearDeAlloc LinearDeAlloc
+static void
+BiLinearDeAlloc(Stitcher * me)
+{
+    LinearDeAlloc(me);
+}
+
+
 
 static bool
 BiLinearAlloc(Stitcher * me)
 {
-    unsigned num;
-    if (LinearAlloc(me) == FALSE) {
-        return FALSE;
-    }
-    for (num = 8; num > 0; --num) {
-        me->parms[num] = 0.0;
-    }
-    /* Unity Transform matrix */
-    me->parms[0] = me->parms[5] = 1.0;
-    return TRUE;
-} /* BiLinearAlloc() - end */
+    return LinearAlloc(me);
+}
+
+
 
 static void
 BiLinearConstrain(Stitcher * me, int x, int y, int width, int height)
