@@ -695,6 +695,9 @@ pnm_writepaminit(struct pam * const pamP) {
     
     switch (PAM_FORMAT_TYPE(pamP->format)) {
     case PAM_TYPE:
+        if (pm_plain_output)
+            pm_error("There is no plain version of PAM.  -plain option "
+                     "is not allowed");
         fprintf(pamP->file, "P7\n");
         fprintf(pamP->file, "WIDTH %d\n",    pamP->width);
         fprintf(pamP->file, "HEIGHT %d\n",   pamP->height);
