@@ -676,7 +676,7 @@ pbm_defaultfont(const char * const name) {
                 l = defaultfont_bits[row][col / 32]; /* initial value */
 
                 for (scol = MIN( col + 32, DEFAULTFONT_COLS) - 1;
-                     scol >= col; 
+                     scol >= (int)col; 
                      --scol) {
                     if (l & 1)
                         defaultfont[row][scol] = 1;
